@@ -1,4 +1,4 @@
-from jumbo_api.objects.store import Store
+from objects.store import Store
 
 
 class Profile(object):
@@ -7,4 +7,4 @@ class Profile(object):
         self.store = Store(data.get("store"))
 
     def __str__(self):
-        return f"{self.id}"
+        return f"{self.id} {self.store}"
