@@ -1,10 +1,11 @@
 from datetime import datetime
 
-from jumbo_api.objects.price import Price
+from objects.price import Price
 
 
 class TimeSlot(object):
     def __init__(self, data):
+        self.type = data.get("type").lower()
         self.start_date_time = datetime.fromtimestamp(int(data.get("startDateTime")) / 1000)
         self.end_date_time = datetime.fromtimestamp(int(data.get("endDateTime")) / 1000)
         self.available = data.get("available")
@@ -18,4 +19,4 @@ class TimeSlot(object):
         return self.available
 
     def __str__(self):
-        return f"{self.start_date_time} {self.end_date_time} {self.available} {self.price}"
+        return f"{self.type} {self.start_date_time} {self.end_date_time} {self.available} {self.price}"
